==> mathmod-7.0.tar.gz: mathmod-7.0/mathmodconfig.js <==
{
    "IsoParam": {
        "MaxGrid": 250,
        "MaxPt": 4,
        "MaxTri": 6,
        "NbComponent": 200,
        "NbVariables": 30,
        "NbConstantes": 40,
        "NbDefinedFunctions": 100,
        "NbTextures": 30,
        "NbSliders": 30,
        "NbSliderValues": 500,
        "InitParGrid": 50,
        "InitIsoGrid": 40

    },
    "WindowPosition": {
        "ControlX": 20,
        "ControlY": 20,
        "GlwinX": 580,
        "GlwinY": 20
    },
    "Localization": {
        "AutomaticDetection": true,
        "DotSymbol": "."
    },
    "WindowSize": {
        "ControlH": 750,
        "ControlW": 538,
        "GlwinH": 750,
        "GlwinW": 750
    },
    "OpenGlConfig": {
        "AtivateGlCache": false,
        "GL_SPECULAR": [50, 50, 50, 100],
        "GL_SHININESS": 110
    },
    "ThreadsConfig": {
        "ThreadsNumber": 6,
        "MinThreadsNumber": 1,
        "MaxThreadsNumber": 64
    },
    "Styles": {
        "PredefinedStyle": [ "Default", "Fusion", "Windows","WindowsXp"],
        "UsedStyle": "Fusion"
    },
    "StartOptions": {
        "Model": "CloseIso_2"
    },
    "Themes": {
        "PredefinedThemes": [ "Default", "Dark", "MyTheme"],
        "UsedTheme": "Dark",
        "MyTheme": {
            "Window":[53,53,53],
            "WindowText":[255, 255, 255],
            "Base":[15,15,15],
            "AlternateBase":[53,53,53],
            "ToolTipBase":[255, 255, 255],
            "ToolTipText":[255, 255, 255],
            "Text":[2, 2, 255],
            "Button":[53,53,53],
            "ButtonText":[255, 255, 255],
            "BrightText":[255, 0, 0],
            "Highlight":[142,45,197],
            "HighlightedText":[0, 0, 0]
        }
    }
}

==> mathmod-11.1.tar.gz: mathmod-11.1/mathmodconfig.js <==
{
    "Version": {
        "Number": 11.1
    },
    "Parameters": {
        "IsoMaxGrid": 500,
        "InitIsoGrid": 64,
        "ParMaxGrid": 5000,
        "InitParGrid": 64
    },
    "StartOptions": {
        "Model": "CloseIso_1"
    },
    "ThreadsConfig": {
        "AutoDetect": true,
        "ThreadsNumber": 8,
        "MinThreadsNumber": 1,
        "MaxThreadsNumber": 64
    },
    "WindowSize": {
        "ControlH": 750,
        "ControlW": 450,
        "GlwinH": 750,
        "GlwinW": 750
    },
    "WindowPosition": {
        "ControlX": 80,
        "ControlY": 30,
        "GlwinX": 535,
        "GlwinY": 30
    },
    "Localization": {
        "AutomaticDetection": true,
        "DotSymbol": "."
    },
    "CalculFactorConfig": {
        "FactX": 4,
        "FactY": 4,
        "FactZ": 4
    },
    "OpenGlConfig": {
        "GL_SPECULAR": [50, 50, 50, 100],
        "GL_AMBIANT" : [50, 50, 50, 100],
        "GL_DIFFUSE" : [80, 80, 80, 100],
        "GL_SHININESS": 20,
        "GL_FrontFacingSupport": true
    },
    "Styles": {
        "PredefinedStyle": [ "Default", "Fusion", "Windows","WindowsXp"],
        "UsedStyle": "Fusion"
    },
    "Themes": {
        "PredefinedThemes": [ "Default", "Dark", "MyTheme"],
        "UsedTheme": "Dark",
        "MyTheme": {
            "Window":[53,53,53],
            "WindowText":[255, 255, 255],
            "Base":[15,15,15],
            "AlternateBase":[53,53,53],
            "ToolTipBase":[255, 255, 255],
            "ToolTipText":[255, 255, 255],
            "Text":[2, 2, 255],
            "Button":[53,53,53],
            "ButtonText":[255, 255, 255],
            "BrightText":[255, 0, 0],
            "Highlight":[142,45,197],
            "HighlightedText":[0, 0, 0]
        }
    }
}
